# Views for article CRUD
from articles.models import Article
from articles_addons.forms import ArticleForm
from django.views.generic.edit import CreateView, UpdateView, DeleteView

class ArticleCreateView(CreateView):
    form_class=ArticleForm
    template_name='articles/post_create.html'

    def get_context_data(self, **kwargs):
        context = super(ArticleCreateView, self).get_context_data(**kwargs)
        return context

class ArticleUpdateView(UpdateView):
    form_class=ArticleForm
    template_name='articles/post_update.html'
    queryset=Article.objects.all()

    def get_context_data(self, **kwargs):
        context = super(ArticleUpdateView, self).get_context_data(**kwargs)
        return context

class ArticleDeleteView(DeleteView):
    model=Article
    template_name='articles/post_delete.html'
    success_url='/articles/' 



from django.forms import ModelForm
from articles.models import Article

class ArticleForm(ModelForm):
  class Meta:
    model = Article
    exclude = ('sites', 'slug', 'is_active', 'login_required', 'followup_for', 'related_articles', 'keywords', 'description', 'auto_tag' )




# -*- coding: utf-8 -*-

# © Copyright 2009 Andre Engelbrecht. All Rights Reserved.
# This script is licensed under the BSD Open Source Licence
# Please see the text file LICENCE for more information
# If this script is distributed, it must be accompanied by the Licence




# -*- coding: utf-8 -*-

import re
import logging

from django import template
from django.conf import settings
from django.db import models

from articles.models import Article

register = template.Library()

@register.tag
def do_get_live_articles(parser, token):
    """
    Gets any number of articles ordered by published date and specified by a tag
    and places them in a varable.

    Syntax::

    {% get_live_articles [count] (tagged [tag]) as [var_name] %}

    Example usage::

    (4) {% get_live_articles 10 as latest_photos %}
    (6) {% get_live_aritlces 10 tagged rabbit as rabbit_photos %}
    (6) {% get_live_articles 10 tagged rabbits,holes as rabbit_hole_photos %}
    
    """
    args = token.split_contents()
    argc = len(args)

    try:
        assert argc in (4,6)
    except AssertionError:
        raise template.TemplateSyntaxError('Invalid get_live_articles syntax.')
    # determine what parameters to use
    count = tags = var_name = None
    if argc == 4: t, count, a, var_name = args
    if argc == 6: t, count, g, tags, a, var_name = args
    return GetArticlesNode(count=count, tags=tags, var_name=var_name)

class GetArticlesNode(template.Node):
    def __init__(self, count, tags, var_name):
        self.count = int(count)
        if tags:
            self.tags = tags.split(',')
        else:
            self.tags = None
        self.var_name = var_name

    def render(self, context):
        if self.tags:
            articles = Article.objects.live().filter(tags__name__in=self.tags)[:self.count]
        else:
            articles = Article.live.all()[:self.count]
        context[self.var_name] = articles 
        return ''

register.tag('get_live_articles', do_get_live_articles)



# Adding URLs for django-articles CRUD
from django.contrib.auth.decorators import login_required, permission_required
from django.conf.urls.defaults import *
from django.views.generic import ListView 
from articles_addons.views import ArticleUpdateView, ArticleCreateView, ArticleDeleteView
from articles.views import display_article

urlpatterns = patterns('',
    url(r'^all/$', login_required(ListView.as_view()), name='articles_list_articles'),
    url(r'^add/$', login_required(ArticleCreateView.as_view()), name='articles_create_article'),
    url(r'^(?P<year>\d{4})/(?P<slug>.*)/update/$', loginrequired(ArticleUpdateView.as_view()), name='articles_update_article'),
    url(r'^(?P<year>\d{4})/(?P<slug>.*)/delete/$', loginrequired(ArticleDeleteView.as_view)), name='articles_delete_article'),
)
